package fi.hsivonen.photobackup;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.net.URL;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;

import javax.xml.parsers.SAXParserFactory;

import nu.validator.xml.NullEntityResolver;
import nu.validator.xml.SilentDraconianErrorHandler;

import org.xml.sax.ContentHandler;
import org.xml.sax.InputSource;
import org.xml.sax.SAXException;
import org.xml.sax.XMLReader;

import com.aetrion.flickr.Parameter;
import com.aetrion.flickr.auth.AuthUtilities;
import com.aetrion.flickr.util.UrlUtilities;

public class FlickrEntityResolver {

    private final String apiKey;
    private final String userId;
    private final String sharedSecret;
    private final File tempDir;
    
    private static byte[] THE_THREAD_UNSAFE_BUFFER = new byte[4096];

    public static final XMLReader newNonvalidatingXMLReader() {
        SAXParserFactory factory = SAXParserFactory.newInstance();
        factory.setNamespaceAware(true);
        factory.setValidating(false);
        try {
            XMLReader reader = factory.newSAXParser().getXMLReader();
            reader.setFeature("http://xml.org/sax/features/string-interning", true);
            reader.setEntityResolver(new NullEntityResolver());
            reader.setErrorHandler(new SilentDraconianErrorHandler());
            return reader;
        } catch (Exception e) {
            throw new RuntimeException(e);
        }
    }
    
    public void callApi(ContentHandler contentHandler, String method, Map<String, Object> arguments) throws SAXException {
        XMLReader reader = newNonvalidatingXMLReader();
        reader.setContentHandler(contentHandler);
        try {
            reader.parse(resolveEntity(method, arguments));
        } catch (IOException e) {
            throw new SAXException(e);
        }
    }
    
    public InputSource resolveEntity(String method, Map<String, Object> arguments) throws IOException, SAXException {
        List parameters = new ArrayList();
        parameters.add(new Parameter("method", method));
        parameters.add(new Parameter("api_key", apiKey));

        if (userId != null) {
            parameters.add(new Parameter("user_id", userId));
        }
        
        for (Map.Entry<String, Object> entry : arguments.entrySet()) {
            parameters.add(new Parameter(entry.getKey(), entry.getValue().toString()));
        }
        
        parameters.add(
            new Parameter(
                "api_sig",
                AuthUtilities.getSignature(sharedSecret, parameters)
            )
        );
        
        URL url = UrlUtilities.buildUrl("www.flickr.com", 80, "/services/rest/", parameters);
        
        File f = File.createTempFile("photobackup_temporary_storage_", ".xml", tempDir);
        
        OutputStream out = new FileOutputStream(f); 
        InputStream in = url.openStream();
        
        int count;
        while ((count = in.read(THE_THREAD_UNSAFE_BUFFER)) != -1) {
            out.write(THE_THREAD_UNSAFE_BUFFER, 0, count);
        }
        out.flush();
        out.close();
        in.close();
        
        return new InputSource(new FileInputStream(f));
    }

    /**
     * @param apiKey
     * @param userId
     * @param sharedSecret
     * @param tempDir 
     */
    public FlickrEntityResolver(String apiKey, String userId, String sharedSecret, File tempDir) {
        this.apiKey = apiKey;
        this.userId = userId;
        this.sharedSecret = sharedSecret;
        this.tempDir = tempDir;
    }
}
